summaryrefslogtreecommitdiff
path: root/arch/x86/machine/pmap.h
diff options
context:
space:
mode:
authorRichard Braun <rbraun@sceen.net>2012-12-22 11:20:15 +0100
committerRichard Braun <rbraun@sceen.net>2012-12-22 11:20:15 +0100
commit3c19fddf9fcda6a8800be28bd84f0e1ee547ae88 (patch)
tree5eed8492e31f0c5698709ee9b214107ada469d61 /arch/x86/machine/pmap.h
parentfa09d42869a1587d28d7f98176d877681d29d027 (diff)
x86/pmap: rename pmap_growkernel to pmap_kgrow
Diffstat (limited to 'arch/x86/machine/pmap.h')
-rw-r--r--arch/x86/machine/pmap.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/arch/x86/machine/pmap.h b/arch/x86/machine/pmap.h
index 3aa75a6..df6a7e8 100644
--- a/arch/x86/machine/pmap.h
+++ b/arch/x86/machine/pmap.h
@@ -153,7 +153,7 @@ unsigned long pmap_bootalloc(unsigned int nr_pages);
/*
* Return the address below which using the kernel pmap functions is safe.
*
* Its value is adjusted by calling pmap_growkernel().
*/
unsigned long pmap_klimit(void);
@@ -164,15 +164,15 @@ unsigned long pmap_klimit(void);
* This function should only be called by the VM system, which makes sure it's
* not called concurrently.
*/
-void pmap_growkernel(unsigned long va);
+void pmap_kgrow(unsigned long va);
/*
* Kernel pmap functions.
*
* These functions assume the caller owns the addresses and don't grab any
* lock. Resources for the new mappings must be preallocated with
* pmap_growkernel(). The TLB isn't flushed, the caller must use pmap_kupdate()
* to explicitely require TLB flushing.
*/
void pmap_kenter(unsigned long va, phys_addr_t pa);
void pmap_kremove(unsigned long start, unsigned long end);
@@ -153,7 +153,7 @@ unsigned long pmap_bootalloc(unsigned int nr_pages);
* Return the address below which using the kernel pmap functions is safe.
*
- * Its value is adjusted by calling pmap_growkernel().
+ * Its value is adjusted by calling pmap_kgrow().
*/
unsigned long pmap_klimit(void);
@@ -164,15 +164,15 @@ unsigned long pmap_klimit(void);
*
* These functions assume the caller owns the addresses and don't grab any
- * lock. Resources for the new mappings must be preallocated with
- * pmap_growkernel(). The TLB isn't flushed, the caller must use pmap_kupdate()
- * to explicitely require TLB flushing.
+ * lock. Resources for the new mappings must be preallocated with pmap_kgrow().
+ * The TLB isn't flushed, the caller must use pmap_kupdate() to explicitely
+ * require TLB flushing.
*/
void pmap_kenter(unsigned long va, phys_addr_t pa);